/*
 * IBM XSLT Processor
 * Licensed Materials - Property of IBM
 * (C) Copyright IBM Corp. 2013.   All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication, or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 */

package org.apache.xml.utils;

import java.security.AccessController;
import java.security.PrivilegedAction;

public class SecurityUtil {
	
	public static final String OVERRIDE_SECURE_PROCESSING_PROP = "com.ibm.xtq.processor.overrideSecureProcessing";
	
	private static final boolean disableExtensionCalls;
	
	static {
		if (System.getSecurityManager() != null) {
			boolean overrideSecureProcessing = false;
			try {
				String prop = (String) AccessController.doPrivileged(
			            new PrivilegedAction() {
			                public Object run() {
			                    return System.getProperty(OVERRIDE_SECURE_PROCESSING_PROP);
			                }
			            }
			        );
				if ("true".equals(prop)) {
					overrideSecureProcessing = true;
				}
			} catch (Throwable t) {
			}
			disableExtensionCalls = !overrideSecureProcessing;
		} else {
			disableExtensionCalls = false;
		}
	}
	
	// Disallow extensions if Java security is enabled, unless system property 
	// SecurityUtil.OVERRIDE_SECURE_PROCESSING_PROP is set to true.
	public static final boolean disableExtensionCalls() {
		return disableExtensionCalls;
	}
}
